import {useRef} from 'react';
import type {Ingredients} from '@/interfaces/Ingredients';
import CheckoutSummary from '@/components/Order/CheckoutSummary/CheckoutSummary';
import { useNavigate, useSearchParams, Outlet } from 'react-router-dom';

const parseSearch = <T extends Object,>(searchParams: URLSearchParams): T => {
    return Object.fromEntries(searchParams) as unknown as T;  
}

const Checkout = () => {
    const navigate = useNavigate();
    const [searchParams] = useSearchParams();
    const ingredients = useRef(parseSearch<Ingredients>(searchParams));

    const checkoutCancelledHandler = () => {
        navigate(-1);
    };
    
    const checkoutContinuedHandler = () => {
        navigate('contact-data', {state: {ingredients: ingredients.current}});
    };

    return (
        <>
            <CheckoutSummary
                ingredients={ingredients.current}
                checkoutCancelled={checkoutCancelledHandler}
                checkoutContinued={checkoutContinuedHandler}
            />
            <Outlet/>
        </>
    )
};

export default Checkout;